@@ -98,6 +98,8 @@ class Properties
         bool useCWD;
         bool m_openNewTabRightToActiveTab;
 
+        bool audibleBell;
+
         QString term;
 
         QString handleHistoryCommand;
@@ -122,6 +124,7 @@ class Properties
         bool trimPastedTrailingNewlines;
 
         bool windowMaximized;
+        bool swapMouseButtons2and3;
 
         bool useFontBoxDrawingChars;
     private:
