@@ -40,7 +40,7 @@ private:
     QList<MainWindow *> m_windowList;
     static QTerminalApp *m_instance;
     QTerminalApp(int &argc, char **argv);
-    ~QTerminalApp(){};
+    ~QTerminalApp() override{};
 };
 
 template <class T> T* findParent(QObject *child)
@@ -48,9 +48,9 @@ template <class T> T* findParent(QObject *child)
     QObject *maybeT = child;
     while (true)
     {
-        if (maybeT == NULL)
+        if (maybeT == nullptr)
         {
-            return NULL;
+            return nullptr;
         }
         T *holder = qobject_cast<T*>(maybeT);
         if (holder)
