@@ -31,6 +31,9 @@
     #include "terminaladaptor.h"
 #endif
 
+#ifdef HAVE_LIBCANBERRA
+    #include <canberra.h>
+#endif
 
 #include "mainwindow.h"
 #include "termwidget.h"
@@ -43,6 +46,9 @@ static int TermWidgetCount = 0;
 
 TermWidgetImpl::TermWidgetImpl(TerminalConfig &cfg, QWidget * parent)
     : QTermWidget(0, parent)
+#ifdef HAVE_LIBCANBERRA
+    , libcanberra_context(nullptr)
+#endif
 {
     TermWidgetCount++;
     QString name(QStringLiteral("TermWidget_%1"));
@@ -64,18 +70,39 @@ TermWidgetImpl::TermWidgetImpl(TerminalConfig &cfg, QWidget * parent)
             setArgs(shell);
     }
 
+    setEnvironment(QStringList(QStringLiteral("TERM=%1").arg(Properties::Instance()->term)));
+
     setMotionAfterPasting(Properties::Instance()->m_motionAfterPaste);
     disableBracketedPasteMode(Properties::Instance()->m_disableBracketedPasteMode);
 
     setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(this, &QWidget::customContextMenuRequested,
-            this, &TermWidgetImpl::customContextMenuCall);
+
+    if(Properties::Instance()->swapMouseButtons2and3)
+    {
+        connect(this, &QWidget::customContextMenuRequested,
+                this, &TermWidgetImpl::pasteSelection);
+    }
+    else
+    {
+        connect(this, &QWidget::customContextMenuRequested,
+                this, &TermWidgetImpl::customContextMenuCall);
+    }
 
     connect(this, &QTermWidget::urlActivated, this, &TermWidgetImpl::activateUrl);
+    connect(this, &QTermWidget::bell, this, &TermWidgetImpl::bell);
 
     startShellProgram();
 }
 
+TermWidgetImpl::~TermWidgetImpl()
+{
+#ifdef HAVE_LIBCANBERRA
+    if (libcanberra_context) {
+        ca_context_destroy (libcanberra_context);
+    }
+#endif
+}
+
 void TermWidgetImpl::propertiesChanged()
 {
     setMargin(Properties::Instance()->terminalMargin);
@@ -205,6 +232,42 @@ void TermWidgetImpl::activateUrl(const QUrl & url, bool fromContextMenu) {
     }
 }
 
+void TermWidgetImpl::bell() {
+    if (Properties::Instance()->audibleBell) {
+#ifdef HAVE_LIBCANBERRA
+        if (!libcanberra_context) {
+            ca_context_create (&libcanberra_context);
+        }
+        ca_context_play (libcanberra_context, 0,
+                         CA_PROP_EVENT_ID, "bell-terminal",
+                         NULL);
+#else
+        qWarning() << "Bell! But QTerminal is not built with libcanberra, so there's no sound.";
+#endif
+    }
+}
+
+bool TermWidget::eventFilter(QObject * /*obj*/, QEvent * ev)
+{
+    if (ev->type() == QEvent::MouseButtonPress)
+    {
+        QMouseEvent *mev = static_cast<QMouseEvent*>(ev);
+        if ( mev->button() == Qt::MiddleButton )
+        {
+            if(Properties::Instance()->swapMouseButtons2and3)
+            {
+                    impl()->customContextMenuCall(mev->pos());
+            }
+            else
+            {
+                    impl()->pasteSelection();
+            }
+            return true;
+        }
+    }
+    return false;
+}
+
 TermWidget::TermWidget(TerminalConfig &cfg, QWidget * parent)
     : QWidget(parent),
       DBusAddressable(QStringLiteral("/terminals"))
@@ -223,6 +286,16 @@ TermWidget::TermWidget(TerminalConfig &cfg, QWidget * parent)
     m_layout->addWidget(m_term);
     const auto objs = m_term->children();
 
+    for (QObject *o : objs)
+    {
+        // Find TerminalDisplay
+        if (!o->isWidgetType() || qobject_cast<QWidget*>(o)->isHidden())
+        {
+            continue;
+        }
+        o->installEventFilter(this);
+    }
+
     propertiesChanged();
 
     connect(m_term, &QTermWidget::finished, this, &TermWidget::finished);
