@@ -25,6 +25,11 @@
 #include <QAction>
 #include "dbusaddressable.h"
 
+#ifdef HAVE_LIBCANBERRA
+// forwarded declaration from <canberra.h>
+struct ca_context;
+#endif
+
 class TermWidgetImpl : public QTermWidget
 {
     Q_OBJECT
@@ -34,6 +39,7 @@ class TermWidgetImpl : public QTermWidget
     public:
 
         TermWidgetImpl(TerminalConfig &cfg, QWidget * parent=nullptr);
+        virtual ~TermWidgetImpl();
         void propertiesChanged();
 
     signals:
@@ -44,10 +50,16 @@ class TermWidgetImpl : public QTermWidget
         void zoomIn();
         void zoomOut();
         void zoomReset();
+        void customContextMenuCall(const QPoint & pos);
 
     private slots:
-        void customContextMenuCall(const QPoint & pos);
         void activateUrl(const QUrl& url, bool fromContextMenu);
+        void bell();
+
+    private:
+#ifdef HAVE_LIBCANBERRA
+        ca_context* libcanberra_context;
+#endif
 };
 
 
@@ -75,6 +87,8 @@ class TermWidget : public QWidget, public DBusAddressable
         void closeTerminal();
         #endif
 
+        bool eventFilter(QObject * obj, QEvent * evt) override;
+
     signals:
         void finished();
         void renameSession();
