@@ -43,7 +43,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="190"/>
         <source>Press &quot;%1&quot; to see the terminal.</source>
-        <translation>Paspauskite &quot;%1&quot;, kad pamatytumėte terminalą.</translation>
+        <translation>Paspauskite „%1“, kad pamatytumėte terminalą.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="239"/>
@@ -371,351 +371,356 @@
         <translation>Terminalo nustatymai</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="31"/>
+        <location filename="../forms/propertiesdialog.ui" line="21"/>
         <source>Appearance</source>
         <translation>Išvaizda</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="39"/>
-        <location filename="../forms/propertiesdialog.ui" line="611"/>
+        <location filename="../forms/propertiesdialog.ui" line="30"/>
+        <location filename="../forms/propertiesdialog.ui" line="581"/>
         <source>Behavior</source>
         <translation>Elgsena</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="47"/>
+        <location filename="../forms/propertiesdialog.ui" line="39"/>
         <source>Shortcuts</source>
         <translation>Spartieji klavišai</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="55"/>
+        <location filename="../forms/propertiesdialog.ui" line="48"/>
         <source>Dropdown</source>
         <translation>Išskleidžiamasis terminalas</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="63"/>
+        <location filename="../forms/propertiesdialog.ui" line="57"/>
         <source>Bookmarks</source>
         <translation>Žymelės</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="258"/>
+        <location filename="../forms/propertiesdialog.ui" line="272"/>
         <source>Hide tab bar with only one tab</source>
         <translation>Slėpti kortelių juostą, esant tik vienai kortelei</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="275"/>
+        <location filename="../forms/propertiesdialog.ui" line="173"/>
         <source>Color scheme</source>
         <translation>Spalvų rinkinys</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="371"/>
+        <location filename="../forms/propertiesdialog.ui" line="199"/>
         <source>Scrollbar position</source>
         <translation>Slankjuostės vieta</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="204"/>
+        <location filename="../forms/propertiesdialog.ui" line="463"/>
         <source>Start with preset:</source>
         <translation>Paleisti su išankstine parinktimi:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="404"/>
+        <location filename="../forms/propertiesdialog.ui" line="299"/>
         <source>Show a border around the current terminal</source>
         <translation>Rodyti rėmelį aplink esamą terminalą</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="381"/>
+        <location filename="../forms/propertiesdialog.ui" line="380"/>
         <source>Terminal transparency</source>
         <translation>Terminalo permatomumas</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="394"/>
+        <location filename="../forms/propertiesdialog.ui" line="354"/>
         <source>Application transparency</source>
         <translation>Programos permatomumas</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="215"/>
+        <location filename="../forms/propertiesdialog.ui" line="474"/>
         <source>None (single terminal)</source>
         <translation>Nėra (vienas terminalas)</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="220"/>
+        <location filename="../forms/propertiesdialog.ui" line="479"/>
         <source>2 terminals horizontally</source>
         <translation>2 horizontalūs terminalai</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="225"/>
+        <location filename="../forms/propertiesdialog.ui" line="484"/>
         <source>2 terminals vertically</source>
         <translation>2 vertikalūs terminalai</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="230"/>
+        <location filename="../forms/propertiesdialog.ui" line="489"/>
         <source>4 terminals</source>
         <translation>4 terminalai</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="117"/>
-        <location filename="../forms/propertiesdialog.ui" line="425"/>
+        <location filename="../forms/propertiesdialog.ui" line="364"/>
+        <location filename="../forms/propertiesdialog.ui" line="390"/>
         <source> %</source>
         <translation> %</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="148"/>
+        <location filename="../forms/propertiesdialog.ui" line="127"/>
         <source>Font</source>
         <translation>Šriftas</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="184"/>
+        <location filename="../forms/propertiesdialog.ui" line="163"/>
         <source>&amp;Change...</source>
         <translation>&amp;Keisti...</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="454"/>
+        <location filename="../forms/propertiesdialog.ui" line="212"/>
         <source>Tabs position</source>
         <translation>Kortelių vieta</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="238"/>
+        <location filename="../forms/propertiesdialog.ui" line="186"/>
         <source>Widget style</source>
         <translation>Valdiklių stilius</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="194"/>
+        <location filename="../forms/propertiesdialog.ui" line="258"/>
         <source>Show the menu bar</source>
         <translation>Rodyti meniu juostą</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="335"/>
+        <location filename="../forms/propertiesdialog.ui" line="225"/>
         <source>Cursor shape</source>
         <translation>Žymeklio forma</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="464"/>
+        <location filename="../forms/propertiesdialog.ui" line="316"/>
         <source>Change window title based on current terminal</source>
         <translation>Keisti lango pavadinimą pagal esamą terminalą</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="481"/>
+        <location filename="../forms/propertiesdialog.ui" line="323"/>
         <source>Change window icon based on current terminal</source>
         <translation>Keisti lango piktogramą pagal esamą terminalą</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="418"/>
+        <location filename="../forms/propertiesdialog.ui" line="337"/>
         <source>Enable bi-directional text support</source>
         <translation>Įjungti dvikrypčio teksto palaikymą</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="265"/>
+        <location filename="../forms/propertiesdialog.ui" line="406"/>
         <source>Background image:</source>
         <translation>Fono paveikslas:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="290"/>
+        <location filename="../forms/propertiesdialog.ui" line="418"/>
         <source>Select</source>
         <translation>Pasirinkti</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="488"/>
+        <location filename="../forms/propertiesdialog.ui" line="330"/>
         <source>Show terminal size on resize</source>
         <translation>Keičiant dydį, rodyti terminalo dydį</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="471"/>
+        <location filename="../forms/propertiesdialog.ui" line="279"/>
         <source>Fixed tab width:</source>
         <translation>Fiksuotas kortelės plotis:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="411"/>
-        <location filename="../forms/propertiesdialog.ui" line="444"/>
+        <location filename="../forms/propertiesdialog.ui" line="289"/>
+        <location filename="../forms/propertiesdialog.ui" line="507"/>
         <source>px</source>
         <translation>piks.</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="361"/>
+        <location filename="../forms/propertiesdialog.ui" line="306"/>
         <source>Show close button on each tab</source>
         <translation>Rodyti ant kiekvienos kortelės užvėrimo mygtuką</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="248"/>
+        <location filename="../forms/propertiesdialog.ui" line="497"/>
         <source>Terminal margin</source>
         <translation>Terminalo paraštė</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="498"/>
+        <location filename="../forms/propertiesdialog.ui" line="347"/>
         <source>Use box drawing characters contained in the font</source>
         <translation>Naudoti šrifte esančius langelio piešimo simbolius</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="505"/>
+        <location filename="../forms/propertiesdialog.ui" line="248"/>
         <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
         <translation>Prieigos klavišai yra aktyvuojami Alt klavišu ir gali trukdyti terminalui.</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="508"/>
+        <location filename="../forms/propertiesdialog.ui" line="251"/>
         <source>No menu bar accelerator</source>
         <translation>Jokių meniu juostos prieigos klavišų</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="586"/>
+        <location filename="../forms/propertiesdialog.ui" line="813"/>
         <source>Emulation</source>
         <translation>Emuliacija</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="711"/>
+        <location filename="../forms/propertiesdialog.ui" line="614"/>
         <source>Action after paste</source>
         <translation>Veiksmas po įdėjimo</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="748"/>
+        <location filename="../forms/propertiesdialog.ui" line="644"/>
         <source>Confirm multiline paste</source>
         <translation>Patvirtinti kelių eilučių įdėjimą</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="789"/>
+        <location filename="../forms/propertiesdialog.ui" line="651"/>
         <source>Trim trailing newlines in pasted text</source>
         <translation>Apkirpti įdėtame tekste naujas eilutes</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="724"/>
+        <location filename="../forms/propertiesdialog.ui" line="747"/>
         <source>Open new terminals in current working directory</source>
         <translation>Atverti naujus terminalus esamame darbiniame kataloge</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="755"/>
+        <location filename="../forms/propertiesdialog.ui" line="682"/>
         <source>Save Size when closing</source>
         <translation>Užveriant, įsiminti dydį</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="796"/>
+        <location filename="../forms/propertiesdialog.ui" line="675"/>
         <source>Save Position when closing</source>
         <translation>Užveriant, įsiminti poziciją</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="772"/>
+        <location filename="../forms/propertiesdialog.ui" line="668"/>
         <source>Ask for confirmation when closing</source>
         <translation>Užveriant, klausti patvirtinimo</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="816"/>
+        <location filename="../forms/propertiesdialog.ui" line="594"/>
         <source>Unlimited history</source>
         <translation>Neribota istorija</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="782"/>
+        <location filename="../forms/propertiesdialog.ui" line="587"/>
         <source>History size (in lines)</source>
         <translation>Istorijos dydis (eilutėmis)</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="741"/>
+        <location filename="../forms/propertiesdialog.ui" line="627"/>
         <source>Default $TERM</source>
         <translation>Numatytasis $TERM</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="632"/>
+        <location filename="../forms/propertiesdialog.ui" line="694"/>
         <source>Start with this size:</source>
         <translation>Paleisti šio dydžio:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="299"/>
+        <location filename="../forms/propertiesdialog.ui" line="427"/>
         <source>Background mode:</source>
         <translation>Foninė veiksena:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="307"/>
+        <location filename="../forms/propertiesdialog.ui" line="435"/>
         <source>None</source>
         <translation>Nėra</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="312"/>
+        <location filename="../forms/propertiesdialog.ui" line="440"/>
         <source>Stretch</source>
         <translation>Ištempti</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="317"/>
+        <location filename="../forms/propertiesdialog.ui" line="445"/>
         <source>Zoom</source>
         <translation>Keisti mastelį</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="322"/>
+        <location filename="../forms/propertiesdialog.ui" line="450"/>
         <source>Fit</source>
         <translation>Priderinti</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="327"/>
+        <location filename="../forms/propertiesdialog.ui" line="455"/>
         <source>Center</source>
         <translation>Centruoti</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="495"/>
+        <location filename="../forms/propertiesdialog.ui" line="344"/>
         <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
         <translation>Nurodo, ar langelį piešiančius simbolius turėtų piešti QTerminal ar bazinės šrifto atvaizdavimo bibliotekos.</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="515"/>
+        <location filename="../forms/propertiesdialog.ui" line="238"/>
         <source>Toggles usage of bold font face for rendering intense colors</source>
         <translation>Perjungia pusjuodžio teksto naudojimą intensyvioms spalvoms atvaizduoti</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="518"/>
+        <location filename="../forms/propertiesdialog.ui" line="241"/>
         <source>Use bold font face for intense colors</source>
         <translation>Ryškioms spalvoms naudoti pusjuodį šriftą</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="525"/>
+        <location filename="../forms/propertiesdialog.ui" line="265"/>
         <source>&amp;Hide Window Borders</source>
         <translation>&amp;Slėpti lango rėmelį</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="595"/>
+        <location filename="../forms/propertiesdialog.ui" line="822"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Kurią veikseną emuliuoti. Turėkite omenyje, kad tai neturi atitikti jūsų operacinę sistemą.&lt;/p&gt;&lt;p&gt;Jei nesate tikri, naudokite &lt;span style=&quot; font-weight:600;&quot;&gt;numatytąją&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Kurią veikseną emuliuoti. Turėkite omenyje, kad tai neturi atitikti jūsų operacinę sistemą.&lt;/p&gt;&lt;p&gt;Jei nesate tikri, naudokite &lt;span style=&quot; font-weight:600;&quot;&gt;numatytąją&lt;/span&gt; emuliaciją.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="617"/>
+        <location filename="../forms/propertiesdialog.ui" line="800"/>
         <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
         <translation>Ši komanda bus paleista su argumentu, kuriame yra nurodytas failo pavadinimas ar laikinasis failas, turintis slinkimo istoriją</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="620"/>
+        <location filename="../forms/propertiesdialog.ui" line="803"/>
         <source>Handle history command</source>
         <translation>Istorijos apdorojimo komanda</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="639"/>
-        <location filename="../forms/propertiesdialog.ui" line="653"/>
+        <location filename="../forms/propertiesdialog.ui" line="701"/>
+        <location filename="../forms/propertiesdialog.ui" line="715"/>
         <source> px</source>
         <translation> piks.</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="660"/>
+        <location filename="../forms/propertiesdialog.ui" line="722"/>
         <source>Get current size</source>
         <translation>Gauti dabartinį dydį</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="731"/>
+        <location filename="../forms/propertiesdialog.ui" line="757"/>
         <source>Open new tab to the right of the active tab</source>
         <translation>Atverti naują kortelę aktyvios kortelės dešinėje</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="734"/>
+        <location filename="../forms/propertiesdialog.ui" line="754"/>
         <source>If unchecked the new tab will be opened as the rightmost tab</source>
         <translation>Jei žymėjimas nuimtas, nauja kortelė bus atveriama pačioje dešinėje</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="762"/>
+        <location filename="../forms/propertiesdialog.ui" line="658"/>
         <source>Close tab on middle-click</source>
         <translation>Užverti kortelę, spustelėjus viduriniuoju pelės mygtuku</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="823"/>
+        <location filename="../forms/propertiesdialog.ui" line="637"/>
         <source>Forcefully disable bracketed paste mode</source>
         <translation>Priverstinai išjungti įdėjimo skliausteliuose veikseną</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="826"/>
+        <location filename="../forms/propertiesdialog.ui" line="634"/>
         <source>Bracketed paste mode is useful for pasting multiline strings.</source>
         <translation>Įdėjimo skliausteliuose veiksena praverčia įdedant kelių eilučių eilutes.</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="844"/>
+        <location filename="../forms/propertiesdialog.ui" line="764"/>
+        <source>Audible bell</source>
+        <translation>Girdimas skambutis</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="846"/>
         <source>To edit a Shortcut:
 1. Double-click its Key
 2. Press the desired combination and release it
@@ -730,78 +735,78 @@ To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</sou
 Norėdami pašalinti/išjungti spartųjį klavišą, 2-ame punkte paspauskite tik modifikatoriaus klavišą, pvz., Lyg2 (Shift)</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="874"/>
+        <location filename="../forms/propertiesdialog.ui" line="876"/>
         <source>Shortcut</source>
         <translation>Spartusis klavišas</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="879"/>
+        <location filename="../forms/propertiesdialog.ui" line="881"/>
         <source>Key</source>
         <translation>Klavišai</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="891"/>
+        <location filename="../forms/propertiesdialog.ui" line="893"/>
         <source>Show on start</source>
         <translation>Rodyti paleisties metu</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="898"/>
+        <location filename="../forms/propertiesdialog.ui" line="900"/>
         <source>A lock button is shown on horizontal tab bar</source>
         <translation>Užrakinimo mygtukas yra rodomas horizontalioje kortelių juostoje</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="901"/>
+        <location filename="../forms/propertiesdialog.ui" line="903"/>
         <source>Keep window open when it loses focus</source>
         <translation>Palikti langą atvertą, kai jis praranda fokusą</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="908"/>
+        <location filename="../forms/propertiesdialog.ui" line="910"/>
         <source>Size</source>
         <translation>Dydis</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="919"/>
+        <location filename="../forms/propertiesdialog.ui" line="921"/>
         <source>Height</source>
         <translation>Aukštis</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="929"/>
-        <location filename="../forms/propertiesdialog.ui" line="946"/>
+        <location filename="../forms/propertiesdialog.ui" line="931"/>
+        <location filename="../forms/propertiesdialog.ui" line="948"/>
         <source>%</source>
         <translation>%</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="936"/>
+        <location filename="../forms/propertiesdialog.ui" line="938"/>
         <source>Width</source>
         <translation>Plotis</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="960"/>
+        <location filename="../forms/propertiesdialog.ui" line="962"/>
         <source>Shortcut:</source>
         <translation>Spartusis klavišas:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="986"/>
+        <location filename="../forms/propertiesdialog.ui" line="1029"/>
         <source>Edit bookmark file contents</source>
         <translation>Redaguoti žymelių failo turinį</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="1008"/>
+        <location filename="../forms/propertiesdialog.ui" line="988"/>
         <source>Enable bookmarks</source>
         <translation>Įjungti žymeles</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="1017"/>
+        <location filename="../forms/propertiesdialog.ui" line="997"/>
         <source>Bookmark file</source>
         <translation>Žymelių failas</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="1030"/>
+        <location filename="../forms/propertiesdialog.ui" line="1010"/>
         <source>Find...</source>
         <translation>Rasti...</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="1039"/>
+        <location filename="../forms/propertiesdialog.ui" line="1019"/>
         <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
         <translation>Jūs galite nurodyti savo asmeninę žymelių failo vietą. Tai leidžia lengvai bendrinti žymeles su tokiais įrankiais kaip OwnCloud ar Dropbox.</translation>
     </message>
@@ -863,66 +868,66 @@ Norėdami pašalinti/išjungti spartųjį klavišą, 2-ame punkte paspauskite ti
         <translation>Slinkimas į apačią</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="262"/>
+        <location filename="../propertiesdialog.cpp" line="268"/>
         <source>Examples</source>
         <translation>Pavyzdžiai</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="410"/>
+        <location filename="../propertiesdialog.cpp" line="421"/>
         <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
         <translation>Paveikslai (*.bmp *.jpg *.png *.svg *.xpm)</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="500"/>
+        <location filename="../propertiesdialog.cpp" line="511"/>
         <source>Open bookmarks file</source>
         <translation>Atverti žymelių failą</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="502"/>
+        <location filename="../propertiesdialog.cpp" line="513"/>
         <source>XML files (*.xml)</source>
         <translation>XML failai (*.xml)</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="503"/>
+        <location filename="../propertiesdialog.cpp" line="514"/>
         <source>All files (*)</source>
         <translation>Visi failai (*)</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="602"/>
-        <location filename="../propertiesdialog.cpp" line="606"/>
+        <location filename="../propertiesdialog.cpp" line="613"/>
+        <location filename="../propertiesdialog.cpp" line="617"/>
         <source>Question</source>
         <translation>Klausimas</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="602"/>
+        <location filename="../propertiesdialog.cpp" line="613"/>
         <source>Do you want to overwrite this bookmarks file?</source>
         <translation>Ar norite perrašyti šį žymelių failą?</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="606"/>
+        <location filename="../propertiesdialog.cpp" line="617"/>
         <source>The name of bookmarks file does not end with &apos;.xml&apos;.
 Are you sure that you want to overwrite it?</source>
         <translation>Žymelių failo pavadinimas nesibaigia prievardžiu „.xml“.
 Ar tikrai norite jį perrašyti?</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="614"/>
+        <location filename="../propertiesdialog.cpp" line="625"/>
         <source>Warning</source>
         <translation>Įspėjimas</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="614"/>
+        <location filename="../propertiesdialog.cpp" line="625"/>
         <source>Cannot write bookmarks to this file:</source>
         <translation>Negalima rašyti žymelių į šį failą:</translation>
     </message>
     <message>
         <location filename="../propertiesdialog.cpp" line="203"/>
-        <location filename="../propertiesdialog.cpp" line="311"/>
+        <location filename="../propertiesdialog.cpp" line="317"/>
         <source>System Default</source>
         <translation>Sistemos numatytasis</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="409"/>
+        <location filename="../propertiesdialog.cpp" line="420"/>
         <source>Choose a background image</source>
         <translation>Pasirinkti fono paveikslą</translation>
     </message>
